/*:
 * @target MZ
 * @plugindesc 選択肢でのキー入力禁止
 * @author GrayOgre
 * @url https://grayogre.info/rmmz/plugin/index.html
 * @help
 *
 * このプラグインは以下の機能を提供します。
 * + 指定されたスイッチがONの場合、選択肢でのキー入力を禁止し
 *   マウス操作のみとし、プレイヤーはマウスでの操作を禁止し
 *   キー操作のみとする。
 *  
 * プラグインコマンドはありません。
 *
 * var 0.9.0
 * 
 * Copyright (c) 2021 GrayOgre
 * Released under the MIT license
 * https://opensource.org/licenses/mit-license.php
 * 
 *
 * @param switchId
 *   @text スイッチ番号
 *   @desc 判定に使用するスイッチ番号
 *   @type number
 *   @min 1
 */

(() => {
    'use strict';

    const pluginName = document.currentScript.src.split("/").pop().replace(/\.js$/, "");

    const parameters = PluginManager.parameters(pluginName);

    const switchId = Number(parameters.switchId || 0);

    const _game_player_canMove = Game_Player.prototype.canMove;
    Game_Player.prototype.canMove = function() {
        if (switchId > 0 && $gameSwitches && $gameSwitches.value(switchId)) {
            if (this.isMoveRouteForcing() || this.areFollowersGathering()) {
                return false;
            }
            if (this._vehicleGettingOn || this._vehicleGettingOff) {
                return false;
            }
            return true;
        } else {
            return _game_player_canMove.call(this);
        }

    };

    const _game_player_moveByInput = Game_Player.prototype.moveByInput;
    Game_Player.prototype.moveByInput = function() {
        if (switchId > 0 && $gameSwitches && $gameSwitches.value(switchId)) {
            if (!this.isMoving() && this.canMove()) {
                let direction = this.getInputDirection();
                if (direction > 0) {
                    $gameTemp.clearDestination();
                }
                if (direction > 0) {
                    this.executeMove(direction);
                }
            }
        } else {
            _game_player_moveByInput.call(this);
        }
    };
    
    const _game_player_triggerAction = Game_Player.prototype.triggerAction;
    Game_Player.prototype.triggerAction = function() {
        if (switchId > 0 && $gameSwitches && $gameSwitches.value(switchId)) {
            if (this.canMove()) {
                if (this.triggerButtonAction()) {
                    return true;
                }
            }
            return false;
        } else {
            return _game_player_triggerAction.call(this);
        }
    };

    const _window_choiceList_update = Window_ChoiceList.prototype.update;
    Window_ChoiceList.prototype.update = function() {
        if (switchId > 0 && $gameSwitches && $gameSwitches.value(switchId)) {
            $gamePlayer.moveByInput();
            this.processTouch();
            Window_Scrollable.prototype.update.call(this);
            this.updateCancelButton();
        } else {
            _window_choiceList_update.call(this);
        }
    };

})();
